[![GitHub Release](https://img.shields.io/github/v/release/mannlabs/scPortrait?logoColor=green&color=brightgreen)](https://github.com/MannLabs/scPortrait/releases)
![Versions](https://img.shields.io/badge/python-3.10_%7C_3.11_%7C_3.12-brightgreen)
[![License](https://img.shields.io/badge/license-Apache-brightgreen)](https://github.com/MannLabs/scPortrait/blob/main/LICENSE)
[![Docs](https://img.shields.io/website?url=https%3A%2F%2Fmannlabs.github.io/scPortrait/index.html)](https://mannlabs.github.io/scPortrait/index.html)
[![PyPI version](https://img.shields.io/pypi/v/scportrait.svg)](https://pypi.org/project/scportrait/)
[![PyPI Downloads](https://static.pepy.tech/badge/scportrait)](https://pepy.tech/projects/scportrait)


![graphical_abstract](https://github.com/user-attachments/assets/02d07c03-243f-4468-8e77-09d703111d11)

scPortrait is a scalable toolkit to generate single-cell representations from raw microscopy images.

## Getting started

Please refer to our [documentation](https://mannlabs.github.io/scPortrait/), in particular:

- [Introduction](https://mannlabs.github.io/scPortrait/pages/workflow.html)
- [Tutorials](https://mannlabs.github.io/scPortrait/pages/tutorials.html)

## Installation from Github

Check out the docs for [complete installation instructions](https://mannlabs.github.io/scPortrait/pages/installation.html). scPortrait currently supports Python 3.10, 3.11 and 3.12.

To get started you can install scPortrait via pip:

```
pip install scportrait
```

### Limitations

Currently the scPortrait framework is being developed using Linux and macOS, and only provides limited Windows support. Please refer to this [GitHub issue](https://github.com/MannLabs/scPortrait/issues/28) for more information.

## Citing our Work

scPortrait was created by Sophia Mädler, Niklas Schmacke and Georg Wallmann in the labs of [Matthias Mann](https://www.biochem.mpg.de/de/mann), [Veit Hornung](https://www.genzentrum.uni-muenchen.de/research-groups/hornung/index.html) and [Fabian Theis](https://www.helmholtz-munich.de/en/icb/research-groups/theis-lab) in 2024 and is actively being developed. If you are interested in contributing please reach out to the developers.

If you use our code please cite [this manuscript](https://www.biorxiv.org/content/10.1101/2023.06.01.542416v1):

SPARCS, a platform for genome-scale CRISPR screening for spatial cellular phenotypes
Niklas Arndt Schmacke, Sophia Clara Maedler, Georg Wallmann, Andreas Metousis, Marleen Berouti, Hartmann Harz, Heinrich Leonhardt, Matthias Mann, Veit Hornung
bioRxiv 2023.06.01.542416; doi: https://doi.org/10.1101/2023.06.01.542416

## Contributing

If you like this software, consider giving us a star to boost our visibility! For detailed guidelines on how to contribute, please refer to our [contributing guide](./docs/CONTRIBUTING.md).

We welcome all types of contributions! You can:

- Post a new [issue](https://github.com/MannLabs/alphapeptstats/issues) if you encounter a bug or have a feature request.
- Clone the repository, create a new branch, and submit a [pull request](https://github.com/MannLabs/scPortrait/pulls).
- Join the conversation in our [discussions](https://github.com/MannLabs/scPortrait/discussions) for more interactive participation.
